==> lowcode-react-simulator-renderer-2.0.5.tgz: package/es/renderer-view.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/extends";
var _excluded = ["__id"];
import React, { createElement, useRef, useEffect } from 'react';
import { BrowserRouter as Router, Route, Routes } from 'react-router-dom';
import cls from 'classnames';
import LowCodeRenderer from '@gant-lowcode/lowcode-react-renderer';
import { observer } from 'mobx-react';
import { getClosestNode, isFromVC, isReactComponent } from '@gant-lowcode/lowcode-utils';
import { GlobalEvent } from '@gant-lowcode/lowcode-types';
import { host } from './host';
import { isRendererDetached } from './utils/misc';
import './renderer.less';
import { createIntl } from './locale';
console.log('--window--', window);
var SimulatorRendererView = observer(function (_ref) {
  var rendererContainer = _ref.rendererContainer;
  return /*#__PURE__*/React.createElement(Layout, {
    rendererContainer: rendererContainer
  }, /*#__PURE__*/React.createElement(Router, {
    basename: window.location.pathname
  }, /*#__PURE__*/React.createElement(Routes, null, rendererContainer.documentInstances.map(function (instance, index) {
    return /*#__PURE__*/React.createElement(Route, {
      index: index === 0,
      path: instance.path,
      key: instance.id,
      element: /*#__PURE__*/React.createElement(Renderer, {
        documentInstance: instance,
        rendererContainer: rendererContainer
      })
    });
  }), /*#__PURE__*/React.createElement(Route, {
    path: "*",
    element: /*#__PURE__*/React.createElement("div", null, "\u8DEF\u7531\u5339\u914D\u9519\u8BEF")
  }))));
});
export default SimulatorRendererView;
function ucfirst(s) {
  return s.charAt(0).toUpperCase() + s.substring(1);
}
function getDeviceView(view, device, mode) {
  if (!view || typeof view === 'string') {
    return view;
  }

  // compatible vision Mobile | Preview
  device = ucfirst(device);
  if (device === 'Mobile' && view.hasOwnProperty(device)) {
    view = view[device];
  }
  mode = ucfirst(mode);
  if (mode === 'Preview' && view.hasOwnProperty(mode)) {
    view = view[mode];
  }
  return view;
}
var Layout = observer(function (_ref2) {
  var rendererContainer = _ref2.rendererContainer,
    children = _ref2.children;
  var layout = rendererContainer.layout;
  if (layout) {
    var Component = layout.Component,
      props = layout.props,
      componentName = layout.componentName;
    if (Component) {
      return /*#__PURE__*/React.createElement(Component, {
        key: "layout",
        props: props
      }, children);
    }
    if (componentName && rendererContainer.getComponent(componentName)) {
      var LayoutComponent = rendererContainer.getComponent(componentName);
      return /*#__PURE__*/React.createElement(LayoutComponent, _extends({
        key: "layout"
      }, props, {
        rendererContainer: rendererContainer
      }), children);
    }
  }
  return children;
});
var Renderer = observer(function (_ref3) {
  var _container$context, _container$context$ut, _container$context$ut2;
  var rendererContainer = _ref3.rendererContainer,
    documentInstance = _ref3.documentInstance;
  var startTimeRef = useRef(null);
  var schemaChangedSymbolRef = useRef(false);
  var container = documentInstance.container,
    document = documentInstance.document;
  var designMode = container.designMode,
    device = container.device,
    locale = container.locale;
  var messages = ((_container$context = container.context) === null || _container$context === void 0 ? void 0 : (_container$context$ut = _container$context.utils) === null || _container$context$ut === void 0 ? void 0 : (_container$context$ut2 = _container$context$ut.i18n) === null || _container$context$ut2 === void 0 ? void 0 : _container$context$ut2.messages) || {};
  var _createIntl = createIntl(locale),
    intl = _createIntl.intl;
  var recordTime = function recordTime() {
    if (startTimeRef.current) {
      var _host$designer$curren, _host$designer$curren2, _host$designer$editor;
      var time = Date.now() - startTimeRef.current;
      var nodeCount = (_host$designer$curren = host.designer.currentDocument) === null || _host$designer$curren === void 0 ? void 0 : (_host$designer$curren2 = _host$designer$curren.getNodeCount) === null || _host$designer$curren2 === void 0 ? void 0 : _host$designer$curren2.call(_host$designer$curren);
      (_host$designer$editor = host.designer.editor) === null || _host$designer$editor === void 0 ? void 0 : _host$designer$editor.eventBus.emit(GlobalEvent.Node.Rerender, {
        componentName: 'Renderer',
        type: 'All',
        time: time,
        nodeCount: nodeCount
      });
    }
  };
  useEffect(function () {
    recordTime();
  });

  // 初始化渲染时间
  startTimeRef.current = Date.now();
  schemaChangedSymbolRef.current = false;
  if (!container.autoRender || isRendererDetached()) {
    return null;
  }
  return /*#__PURE__*/React.createElement(LowCodeRenderer, {
    locale: locale,
    messages: messages,
    schema: documentInstance.schema,
    components: container.components,
    appHelper: container.context,
    designMode: designMode,
    device: device,
    documentId: document.id,
    suspended: rendererContainer.suspended,
    self: rendererContainer.scope,
    getSchemaChangedSymbol: function getSchemaChangedSymbol() {
      return schemaChangedSymbolRef.current;
    },
    setSchemaChangedSymbol: function setSchemaChangedSymbol(symbol) {
      return schemaChangedSymbolRef.current = symbol;
    },
    getNode: function getNode(id) {
      return documentInstance.getNode(id);
    },
    rendererName: "PageRenderer",
    notFoundComponent: host.notFoundComponent,
    faultComponent: host.faultComponent,
    faultComponentMap: host.faultComponentMap,
    customCreateElement: function customCreateElement(Component, props, children) {
      var __id = props.__id,
        viewProps = _objectWithoutPropertiesLoose(props, _excluded);
      viewProps.componentId = __id;
      var leaf = documentInstance.getNode(__id);
      if (isFromVC(leaf === null || leaf === void 0 ? void 0 : leaf.componentMeta)) {
        viewProps._leaf = leaf.internalToShellNode();
      }
      viewProps._componentName = leaf === null || leaf === void 0 ? void 0 : leaf.componentName;
      // 如果是容器 && 无children && 高宽为空 增加一个占位容器，方便拖动
      if (!viewProps.dataSource && leaf !== null && leaf !== void 0 && leaf.isContainer() && (children == null || Array.isArray(children) && !children.length) && (!viewProps.style || Object.keys(viewProps.style).length === 0)) {
        var defaultPlaceholder = intl('Drag and drop components or templates here');
        var lockedNode = getClosestNode(leaf, function (node) {
          var _node$getExtraProp;
          return (node === null || node === void 0 ? void 0 : (_node$getExtraProp = node.getExtraProp('isLocked')) === null || _node$getExtraProp === void 0 ? void 0 : _node$getExtraProp.getValue()) === true;
        });
        if (lockedNode) {
          defaultPlaceholder = intl('Locked elements and child elements cannot be edited');
        }
        children = /*#__PURE__*/React.createElement("div", {
          className: cls('lc-container-placeholder', {
            'lc-container-locked': !!lockedNode
          }),
          style: viewProps.placeholderStyle
        }, viewProps.placeholder || defaultPlaceholder);
      }
      if (viewProps._componentName === 'a') {
        delete viewProps.href;
      }
      // FIXME: 渲染仍有问题
      if (viewProps._componentName === 'Menu') {
        Object.assign(viewProps, {
          _componentName: 'Menu',
          className: '_css_pesudo_menu_kbrzyh0f',
          context: {
            VE: window.VisualEngine
          },
          direction: undefined,
          events: {
            ignored: true
          },
          fieldId: 'menu_kbrzyh0f',
          footer: '',
          header: '',
          mode: 'inline',
          onItemClick: {
            ignored: true
          },
          onSelect: {
            ignored: true
          },
          popupAlign: 'follow',
          selectMode: false,
          triggerType: 'click'
        });
      }
      if (!isReactComponent(Component)) {
        console.error(viewProps._componentName + " is not a react component!");
        return null;
      }
      return /*#__PURE__*/createElement(getDeviceView(Component, device, designMode), viewProps, leaf !== null && leaf !== void 0 && leaf.isContainer() ? children == null ? [] : Array.isArray(children) ? children : [children] : children);
    },
    __host: host,
    __container: container,
    onCompGetRef: function onCompGetRef(schema, ref) {
      documentInstance.mountInstance(schema.id, ref);
    },
    enableStrictNotFoundMode: host.enableStrictNotFoundMode
  });
});

==> lowcode-react-simulator-renderer-2.0.8.tgz: package/es/renderer-view.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/extends";
var _excluded = ["__id"];
import React, { createElement, useRef, useEffect } from 'react';
import { BrowserRouter as Router, Route, Routes } from 'react-router-dom';
import cls from 'classnames';
import LowCodeRenderer from '@gant-lowcode/lowcode-react-renderer';
import { observer } from 'mobx-react';
import { getClosestNode, isFromVC, isReactComponent } from '@gant-lowcode/lowcode-utils';
import { GlobalEvent } from '@gant-lowcode/lowcode-types';
import { host } from './host';
import { isRendererDetached } from './utils/misc';
import './renderer.less';
import { createIntl } from './locale';
console.log('--window--', window);
var SimulatorRendererView = observer(function (_ref) {
  var rendererContainer = _ref.rendererContainer;
  return /*#__PURE__*/React.createElement(Layout, {
    rendererContainer: rendererContainer
  }, /*#__PURE__*/React.createElement(Router, {
    basename: window.location.pathname
  }, /*#__PURE__*/React.createElement(Routes, null, rendererContainer.documentInstances.map(function (instance, index) {
    return /*#__PURE__*/React.createElement(Route, {
      index: index === 0,
      path: instance.path,
      key: instance.id,
      element: /*#__PURE__*/React.createElement(Renderer, {
        documentInstance: instance,
        rendererContainer: rendererContainer
      })
    });
  }), /*#__PURE__*/React.createElement(Route, {
    path: "*",
    element: /*#__PURE__*/React.createElement("div", null, "\u8DEF\u7531\u5339\u914D\u9519\u8BEF")
  }))));
});
export default SimulatorRendererView;
function ucfirst(s) {
  return s.charAt(0).toUpperCase() + s.substring(1);
}
function getDeviceView(view, device, mode) {
  if (!view || typeof view === 'string') {
    return view;
  }

  // compatible vision Mobile | Preview
  device = ucfirst(device);
  if (device === 'Mobile' && view.hasOwnProperty(device)) {
    view = view[device];
  }
  mode = ucfirst(mode);
  if (mode === 'Preview' && view.hasOwnProperty(mode)) {
    view = view[mode];
  }
  return view;
}
var Layout = observer(function (_ref2) {
  var rendererContainer = _ref2.rendererContainer,
    children = _ref2.children;
  var layout = rendererContainer.layout;
  if (layout) {
    var Component = layout.Component,
      props = layout.props,
      componentName = layout.componentName;
    if (Component) {
      return /*#__PURE__*/React.createElement(Component, {
        key: "layout",
        props: props
      }, children);
    }
    if (componentName && rendererContainer.getComponent(componentName)) {
      var LayoutComponent = rendererContainer.getComponent(componentName);
      return /*#__PURE__*/React.createElement(LayoutComponent, _extends({
        key: "layout"
      }, props, {
        rendererContainer: rendererContainer
      }), children);
    }
  }
  return children;
});
var Renderer = observer(function (_ref3) {
  var _container$context, _container$context$ut, _container$context$ut2;
  var rendererContainer = _ref3.rendererContainer,
    documentInstance = _ref3.documentInstance;
  var startTimeRef = useRef(null);
  var schemaChangedSymbolRef = useRef(false);
  var container = documentInstance.container,
    document = documentInstance.document;
  var designMode = container.designMode,
    device = container.device,
    locale = container.locale;
  var messages = ((_container$context = container.context) === null || _container$context === void 0 ? void 0 : (_container$context$ut = _container$context.utils) === null || _container$context$ut === void 0 ? void 0 : (_container$context$ut2 = _container$context$ut.i18n) === null || _container$context$ut2 === void 0 ? void 0 : _container$context$ut2.messages) || {};
  var _createIntl = createIntl(locale),
    intl = _createIntl.intl;
  var recordTime = function recordTime() {
    if (startTimeRef.current) {
      var _host$designer$curren, _host$designer$curren2, _host$designer$editor;
      var time = Date.now() - startTimeRef.current;
      var nodeCount = (_host$designer$curren = host.designer.currentDocument) === null || _host$designer$curren === void 0 ? void 0 : (_host$designer$curren2 = _host$designer$curren.getNodeCount) === null || _host$designer$curren2 === void 0 ? void 0 : _host$designer$curren2.call(_host$designer$curren);
      (_host$designer$editor = host.designer.editor) === null || _host$designer$editor === void 0 ? void 0 : _host$designer$editor.eventBus.emit(GlobalEvent.Node.Rerender, {
        componentName: 'Renderer',
        type: 'All',
        time: time,
        nodeCount: nodeCount
      });
    }
  };
  useEffect(function () {
    recordTime();
  });

  // 初始化渲染时间
  startTimeRef.current = Date.now();
  schemaChangedSymbolRef.current = false;
  if (!container.autoRender || isRendererDetached()) {
    return null;
  }
  return /*#__PURE__*/React.createElement(LowCodeRenderer, {
    locale: locale,
    messages: messages,
    schema: documentInstance.schema,
    components: container.components,
    appHelper: container.context,
    designMode: designMode,
    device: device,
    documentId: document.id,
    suspended: rendererContainer.suspended,
    self: rendererContainer.scope,
    getSchemaChangedSymbol: function getSchemaChangedSymbol() {
      return schemaChangedSymbolRef.current;
    },
    setSchemaChangedSymbol: function setSchemaChangedSymbol(symbol) {
      return schemaChangedSymbolRef.current = symbol;
    },
    getNode: function getNode(id) {
      return documentInstance.getNode(id);
    },
    rendererName: "PageRenderer",
    notFoundComponent: host.notFoundComponent,
    faultComponent: host.faultComponent,
    faultComponentMap: host.faultComponentMap,
    customCreateElement: function customCreateElement(Component, props, children) {
      var __id = props.__id,
        viewProps = _objectWithoutPropertiesLoose(props, _excluded);
      viewProps['data-component-id'] = __id;
      var leaf = documentInstance.getNode(__id);
      if (isFromVC(leaf === null || leaf === void 0 ? void 0 : leaf.componentMeta)) {
        viewProps._leaf = leaf.internalToShellNode();
      }
      viewProps['data-component-name'] = leaf === null || leaf === void 0 ? void 0 : leaf.componentName;
      // 如果是容器 && 无children && 高宽为空 增加一个占位容器，方便拖动
      if (!viewProps.dataSource && leaf !== null && leaf !== void 0 && leaf.isContainer() && (children == null || Array.isArray(children) && !children.length) && (!viewProps.style || Object.keys(viewProps.style).length === 0)) {
        var defaultPlaceholder = intl('Drag and drop components or templates here');
        var lockedNode = getClosestNode(leaf, function (node) {
          var _node$getExtraProp;
          return (node === null || node === void 0 ? void 0 : (_node$getExtraProp = node.getExtraProp('isLocked')) === null || _node$getExtraProp === void 0 ? void 0 : _node$getExtraProp.getValue()) === true;
        });
        if (lockedNode) {
          defaultPlaceholder = intl('Locked elements and child elements cannot be edited');
        }
        children = /*#__PURE__*/React.createElement("div", {
          key: "lc-container-placeholder",
          className: cls('lc-container-placeholder', {
            'lc-container-locked': !!lockedNode
          }),
          style: viewProps.placeholderStyle
        }, viewProps.placeholder || defaultPlaceholder);
      }
      if (viewProps['data-component-name'] === 'a') {
        delete viewProps.href;
      }
      // FIXME: 渲染仍有问题
      if (viewProps['data-component-name'] === 'Menu') {
        Object.assign(viewProps, {
          _componentName: 'Menu',
          className: '_css_pesudo_menu_kbrzyh0f',
          context: {
            VE: window.VisualEngine
          },
          direction: undefined,
          events: {
            ignored: true
          },
          fieldId: 'menu_kbrzyh0f',
          footer: '',
          header: '',
          mode: 'inline',
          onItemClick: {
            ignored: true
          },
          onSelect: {
            ignored: true
          },
          popupAlign: 'follow',
          selectMode: false,
          triggerType: 'click'
        });
      }
      if (!isReactComponent(Component)) {
        console.error(viewProps['data-component-name'] + " is not a react component!");
        return null;
      }
      return /*#__PURE__*/createElement(getDeviceView(Component, device, designMode), viewProps, leaf !== null && leaf !== void 0 && leaf.isContainer() ? children == null ? [] : Array.isArray(children) ? children : [children] : children);
    },
    __host: host,
    __container: container,
    onCompGetRef: function onCompGetRef(schema, ref) {
      documentInstance.mountInstance(schema.id, ref);
    },
    enableStrictNotFoundMode: host.enableStrictNotFoundMode
  });
});
